use uuid::Uuid;

use super::schema::DbHook;

const METHOD_TOTP: &'static str = "totp";

/// Checks that the provided user has at least one OTP method enabled
pub async fn has_otp(db: &mut DbHook, id: &Uuid) -> sqlx::Result<bool> {
	sqlx::query_scalar!("select count(otp_method) from otp where user_id = $1", id)
		.fetch_one(&mut **db)
		.await
		.map(|count| count.unwrap_or(0) > 0)
}

pub async fn add_otp_method(
	db: &mut DbHook,
	id: &Uuid,
	secret: &str,
	hashed_recovery_key: &str,
) -> sqlx::Result<()> {
	sqlx::query!(
		"insert into otp (user_id, otp_method, secret_seed, recovery_key) values ($1, $2, $3, $4)",
		id,
		METHOD_TOTP,
		secret,
		hashed_recovery_key,
	)
	.execute(&mut **db)
	.await?;

	Ok(())
}
